@@ -52,6 +52,9 @@ class TrytonConfigParser(ConfigParser.RawConfigParser):
         self.set('database', 'list', 'True')
         self.set('database', 'retry', 5)
         self.set('database', 'language', 'en')
+        self.add_section('request')
+        self.set('request', 'max_size', 2 * 1024 * 1024)
+        self.set('request', 'max_size_authenticated', 2 * 1024 * 1024 * 1024)
         self.add_section('cache')
         self.set('cache', 'model', 200)
         self.set('cache', 'record', 2000)
