@@ -1,11 +1,13 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
+import sys
 
 
 class TrytonException(Exception):
 
-    def __str__(self):
-        return unicode(self).encode('utf-8')
+    if sys.version_info < (3, ):
+        def __str__(self):
+            return unicode(self).encode('utf-8')
 
 
 class UserError(TrytonException):
