@@ -7,7 +7,6 @@ from .sequence import *
 from .ui.menu import *
 from .ui.view import *
 from .ui.icon import *
-from .property import *
 from .action import *
 from .model import *
 from .attachment import *
@@ -45,7 +44,6 @@ def register():
         ViewTreeState,
         ViewSearch,
         Icon,
-        Property,
         Action,
         ActionKeyword,
         ActionReport,
@@ -59,6 +57,9 @@ def register():
         ModelAccess,
         ModelFieldAccess,
         ModelButton,
+        ModelButtonRule,
+        ModelButtonClick,
+        ModelButtonReset,
         ModelData,
         PrintModelGraphStart,
         Attachment,
@@ -76,8 +77,8 @@ def register():
         ModuleConfigWizardFirst,
         ModuleConfigWizardOther,
         ModuleConfigWizardDone,
-        ModuleInstallUpgradeStart,
-        ModuleInstallUpgradeDone,
+        ModuleActivateUpgradeStart,
+        ModuleActivateUpgradeDone,
         Cache,
         Date,
         Trigger,
@@ -90,10 +91,11 @@ def register():
         TranslationClean,
         TranslationUpdate,
         TranslationExport,
+        TranslationReport,
         ShowView,
         PrintModelGraph,
         ModuleConfigWizard,
-        ModuleInstallUpgrade,
+        ModuleActivateUpgrade,
         ModuleConfig,
         module='ir', type_='wizard')
     Pool.register(
