@@ -14,7 +14,6 @@ from ..transaction import Transaction
 from ..pool import Pool
 from .. import backend
 from ..config import config
-from ..cache import Cache
 from ..sendmail import sendmail
 
 __all__ = [
@@ -143,7 +142,9 @@ class Cron(ModelSQL, ModelView):
         with Transaction().set_user(self.user.id), \
                 Transaction().set_context(language=language):
             tb_s = ''.join(traceback.format_exception(*sys.exc_info()))
-            tb_s = tb_s.decode('utf-8', 'ignore')
+            # On Python3, the traceback is already a unicode
+            if hasattr(tb_s, 'decode'):
+                tb_s = tb_s.decode('utf-8', 'ignore')
             subject = self.raise_user_error('request_title',
                 raise_exception=False)
             body = self.raise_user_error('request_body',
@@ -179,7 +180,6 @@ class Cron(ModelSQL, ModelView):
     def run(cls, db_name):
         now = datetime.datetime.now()
         with Transaction().start(db_name, 0) as transaction:
-            Cache.clean(db_name)
             transaction.database.lock(transaction.connection, cls._table)
             crons = cls.search([
                     ('number_calls', '!=', 0),
@@ -212,4 +212,3 @@ class Cron(ModelSQL, ModelView):
                 except Exception:
                     transaction.rollback()
                     logger.error('Running cron %s', cron.id, exc_info=True)
-            Cache.resets(db_name)
