@@ -1,11 +1,12 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from sql import Query, Expression, Literal
+from sql import Literal, Column
+from sql.aggregate import Max
+from sql.conditionals import Coalesce
 from sql.operators import Or
 
-from .field import Field, SQLType
+from .field import Field
 from ...pool import Pool
-from ... import backend
 from ...tools import reduce_ids
 from ...transaction import Transaction
 
@@ -15,6 +16,7 @@ class Many2One(Field):
     Define many2one field (``int``).
     '''
     _type = 'many2one'
+    _sql_type = 'INTEGER'
 
     def __init__(self, model_name, string='', left=None, right=None,
             ondelete='SET NULL', datetime_field=None, target_search='join',
@@ -78,24 +80,12 @@ class Many2One(Field):
         assert isinstance(value, (Target, type(None)))
         super(Many2One, self).__set__(inst, value)
 
-    @staticmethod
-    def sql_format(value):
-        if isinstance(value, (Query, Expression)):
-            return value
+    def sql_format(self, value):
         if value is None:
             return None
         assert value is not False
         return int(value)
 
-    def sql_type(self):
-        db_type = backend.name()
-        if db_type == 'postgresql':
-            return SQLType('INT4', 'INT4')
-        elif db_type == 'mysql':
-            return SQLType('SIGNED INTEGER', 'BIGINT')
-        else:
-            return SQLType('INTEGER', 'INTEGER')
-
     def convert_domain_mptt(self, domain, tables):
         cursor = Transaction().connection.cursor()
         table, _ = tables[None]
@@ -195,6 +185,14 @@ class Many2One(Field):
                     return self.convert_domain_tree(
                         (name, operator, ids), tables)
 
+            # Used for Many2Many where clause
+            if operator.endswith('where'):
+                query = Target.search(value, order=[], query=True)
+                expression = column.in_(query)
+                if operator.startswith('not'):
+                    return ~expression
+                return expression
+
             if not isinstance(value, basestring):
                 return super(Many2One, self).convert_domain(domain, tables,
                     Model)
@@ -248,13 +246,27 @@ class Many2One(Field):
         Target = self.get_target()
         table, _ = tables[None]
         target_tables = tables.get(self.name)
+        context = Transaction().context
         if target_tables is None:
-            if Target._history and Transaction().context.get('_datetime'):
+            if Target._history and context.get('_datetime'):
                 target = Target.__table_history__()
+                target_history = Target.__table_history__()
+                history_condition = Column(target, '__id').in_(
+                    target_history.select(
+                        Max(Column(target_history, '__id')),
+                        where=Coalesce(
+                            target_history.write_date,
+                            target_history.create_date)
+                        <= context['_datetime'],
+                        group_by=target_history.id))
             else:
                 target = Target.__table__()
+                history_condition = None
+            condition = target.id == self.sql_column(table)
+            if history_condition:
+                condition &= history_condition
             target_tables = {
-                None: (target, target.id == self.sql_column(table)),
+                None: (target, condition),
                 }
             tables[self.name] = target_tables
         return target_tables
