@@ -1,10 +1,9 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from decimal import Decimal
-from sql import Query, Expression, Cast, Literal, Select, CombiningQuery, As
+from sql import Cast, Literal, Select, CombiningQuery, As
 
 from ... import backend
-from .field import SQLType
 from .float import Float
 
 
@@ -20,11 +19,9 @@ class Numeric(Float):
     Define a numeric field (``decimal``).
     '''
     _type = 'numeric'
+    _sql_type = 'NUMERIC'
 
-    @staticmethod
-    def sql_format(value):
-        if isinstance(value, (Query, Expression)):
-            return value
+    def sql_format(self, value):
         if value is None:
             return None
         if isinstance(value, (int, long)):
@@ -32,12 +29,6 @@ class Numeric(Float):
         assert isinstance(value, Decimal)
         return value
 
-    def sql_type(self):
-        db_type = backend.name()
-        if db_type == 'mysql':
-            return SQLType('DECIMAL', 'DECIMAL(65, 30)')
-        return SQLType('NUMERIC', 'NUMERIC')
-
     def sql_column(self, table):
         column = super(Numeric, self).sql_column(table)
         db_type = backend.name()
