@@ -3,12 +3,10 @@
 "Group"
 from itertools import chain
 from ..model import ModelView, ModelSQL, fields, Unique
-from ..pool import Pool, PoolMeta
+from ..pool import Pool
 from ..tools import grouped_slice
 
-__all__ = [
-    'Group', 'Group2',
-    ]
+__all__ = ['Group']
 
 
 class MenuMany2Many(fields.Many2Many):
@@ -33,10 +31,13 @@ class Group(ModelSQL, ModelView):
     "Group"
     __name__ = "res.group"
     name = fields.Char('Name', required=True, select=True, translate=True)
+    users = fields.Many2Many('res.user-res.group', 'group', 'user', 'Users')
     model_access = fields.One2Many('ir.model.access', 'group',
        'Access Model')
     field_access = fields.One2Many('ir.model.field.access', 'group',
         'Access Field')
+    buttons = fields.Many2Many(
+        'ir.model.button-res.group', 'group', 'button', "Buttons")
     rule_groups = fields.Many2Many('ir.rule.group-res.group',
        'group', 'rule_group', 'Rules',
        domain=[('global_p', '!=', True), ('default_p', '!=', True)])
@@ -115,9 +116,3 @@ class Group(ModelSQL, ModelView):
         pool.get('ir.model.access')._get_access_cache.clear()
         pool.get('ir.model.field.access')._get_access_cache.clear()
         ModelView._fields_view_get_cache.clear()
-
-
-class Group2:
-    __metaclass__ = PoolMeta
-    __name__ = "res.group"
-    users = fields.Many2Many('res.user-res.group', 'group', 'user', 'Users')
