@@ -1,6 +1,12 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 
+try:
+    import pkg_resources
+except ImportError:
+    pkg_resources = None
+
+
 from ..pool import Pool
 from .test import *
 from .model import *
@@ -108,6 +114,7 @@ def register():
         Dict,
         DictDefault,
         DictRequired,
+        DictJSONB,
         Binary,
         BinaryDefault,
         BinaryRequired,
@@ -138,6 +145,7 @@ def register():
         ModelViewChangedValuesTarget,
         ModelViewButton,
         ModelViewRPC,
+        ModelViewEmptyPage,
         MPTT,
         ImportDataBoolean,
         ImportDataInteger,
@@ -199,6 +207,13 @@ def register():
 
     multivalue.register('tests')
 
+    if pkg_resources is not None:
+        entry_points = pkg_resources.iter_entry_points('trytond.tests')
+        for test_ep in entry_points:
+            test_module = test_ep.load()
+            if hasattr(test_module, 'register'):
+                test_module.register('tests')
+
 
 def suite():
     from .test_tryton import all_suite
