@@ -6,6 +6,7 @@ from trytond.transaction import Transaction
 
 __all__ = [
     'Model',
+    'ModelParent', 'ModelChild', 'ModelChildChild',
     'Singleton', 'URLObject',
     'ModelStorage', 'ModelStorageRequired', 'ModelStorageContext',
     'ModelSQLRequiredField', 'ModelSQLTimestamp', 'ModelSQLFieldSet',
@@ -13,6 +14,7 @@ __all__ = [
     'Union', 'UnionUnion',
     'Model4UnionTree1', 'Model4UnionTree2', 'UnionTree',
     'SequenceOrderedModel',
+    'NullOrder',
     ]
 
 
@@ -22,6 +24,26 @@ class Model(ModelSQL):
     name = fields.Char('Name')
 
 
+class ModelParent(Model):
+    "Model Parent"
+    __name__ = 'test.model_parent'
+    name = fields.Char("Name")
+
+
+class ModelChild(Model):
+    "Model Child"
+    __name__ = 'test.model_child'
+    name = fields.Char("Name")
+    parent = fields.Many2One('test.model_parent', "Parent")
+
+
+class ModelChildChild(Model):
+    "Model Child Child"
+    __name__ = 'test.model_child_child'
+    name = fields.Char("Name")
+    parent = fields.Many2One('test.model_child', "Parent")
+
+
 class Singleton(ModelSingleton, ModelSQL):
     'Singleton'
     __name__ = 'test.singleton'
@@ -161,3 +183,9 @@ class UnionTree(UnionMixin, ModelSQL):
 class SequenceOrderedModel(sequence_ordered(), ModelSQL):
     'Sequence Ordered Model'
     __name__ = 'test.order.sequence'
+
+
+class NullOrder(ModelSQL):
+    "Null Order"
+    __name__ = 'test.null_order'
+    integer = fields.Integer('Integer')
