@@ -4,7 +4,7 @@
 import unittest
 from decimal import InvalidOperation
 
-from trytond.tests.test_tryton import install_module, with_transaction
+from trytond.tests.test_tryton import activate_module, with_transaction
 from trytond.transaction import Transaction
 from trytond.pool import Pool
 from trytond.exceptions import UserError
@@ -15,7 +15,7 @@ class ImportDataTestCase(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        install_module('tests')
+        activate_module('tests')
 
     @with_transaction()
     def test_boolean(self):
