@@ -9,7 +9,7 @@ import sql
 import sql.operators
 
 from trytond.tools import reduce_ids, datetime_strftime, \
-    reduce_domain, decimal_, is_instance_method
+    reduce_domain, decimal_, is_instance_method, file_open
 
 
 class ToolsTestCase(unittest.TestCase):
@@ -65,6 +65,12 @@ class ToolsTestCase(unittest.TestCase):
             '%Y-%m-%d'), '2005-03-02')
         self.assert_(datetime_strftime(datetime.date(1805, 3, 2),
             '%Y-%m-%d'), '1805-03-02')
+        self.assert_(datetime_strftime(datetime.datetime(2005, 3, 2, 0, 0, 0),
+            '%Y-%m-%d'), '2005-03-02')
+        with self.assertRaises(TypeError):
+            datetime_strftime(None, '%Y-%m-%d')
+        with self.assertRaises(TypeError):
+            datetime_strftime(2, '%Y-%m-%d')
 
     def test_reduce_domain(self):
         'Test reduce_domain'
@@ -114,6 +120,25 @@ class ToolsTestCase(unittest.TestCase):
         self.assertFalse(is_instance_method(Foo, 'klass'))
         self.assertTrue(is_instance_method(Foo, 'instance'))
 
+    def test_file_open(self):
+        "Test file_open"
+        self.assertTrue(file_open('__init__.py', subdir=None))
+        self.assertTrue(file_open('ir/__init__.py'))
+
+        with self.assertRaisesRegexp(IOError, "File not found :"):
+            file_open('ir/noexist')
+
+        with self.assertRaisesRegexp(IOError, "Permission denied:"):
+            file_open('/etc/passwd')
+
+        with self.assertRaisesRegexp(IOError, "Permission denied:"):
+            file_open('../../foo')
+
+    def test_file_open_suffix(self):
+        "Test file_open from same root name but with a suffix"
+        with self.assertRaisesRegexp(IOError, "Permission denied:"):
+            file_open('../trytond_suffix', subdir=None)
+
 
 def suite():
     func = unittest.TestLoader().loadTestsFromTestCase
